#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Oct 29 10:09:36 2019

@author: lessig
"""

import numpy as np
import matplotlib.pyplot as plt

from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
from matplotlib import cm
from matplotlib.ticker import LinearLocator, FormatStrFormatter


xmin = -5.;
xmax = 5.;
tmax = 5;
dx = 0.04 * np.pi;
dt = 0.04 * np.pi;
vel = -1.;

x = np.arange( xmin, xmax, dx)
grad = np.zeros( x.size)

# Gaussian
y = np.exp( -(x-0.5)**2/0.5)

yhist = np.zeros( (np.arange(0,tmax,dt).size, y.size))
yhist[0] = y

for i in range( yhist.shape[0]-1) :

  # upwind
  grad[:-1] = (y[:-1] - y[1:]) / dx
  y = y + dt * vel * grad

  yhist[i+1] = y


## Plotting

fig = plt.figure(figsize=( 10, 10))
ax = fig.gca(projection='3d')

tvals = np.arange( 0, yhist.shape[0])
x_grid, t_grid = np.meshgrid( x, tvals)

# Plot the surface.
surf = ax.plot_surface( x_grid, t_grid, yhist, cmap=cm.coolwarm,
                       linewidth=0, antialiased=True)

# Customize the z axis.
ax.set_zlim(-1.01, 1.01)
ax.zaxis.set_major_locator(LinearLocator(10))
ax.zaxis.set_major_formatter(FormatStrFormatter('%.02f'))

plt.show()
